import React from 'react'
import cx from 'classnames';
import PropTypes from 'prop-types'
import { noop } from './utils'
import isEmpty from 'is-empty';

const Input = props => {
  const {
    value,
    onChange,
    onBlur,
    onFocus,
    inputClasses,
    icons,
    inputRef,
    placeHolder,
    readOnly,
    disabled,
    loading,
    ...inputProps
  } = props;

  const hasLeftIcon = !isEmpty(icons.left.component);
  const hasRightIcon = !isEmpty(icons.right.component);

  return (
    <div className='pk-select-input-wrapper'>
      {
        hasLeftIcon ?
          <span className={cx('pk-select-input-icon icon-left', icons.left.additionalClasses)} onClick={() => icons.left.onClick()}>
            {icons.left.component}
          </span>
          :
          null
      }
      {
        disabled ?
          <input
            className={cx('pk-select-input')}
            defaultValue={props.value}
            disabled
          />
          :
          <input
            className={cx('pk-select-input', inputClasses, { 'has-left-icon': hasLeftIcon, 'has-right-icon': hasRightIcon, 'read-only': readOnly })}
            onChange={onChange}
            onBlur={onBlur}
            onFocus={onFocus}
            value={value}
            ref={inputRef}
            placeholder={placeHolder}
            readOnly={readOnly}
            {...inputProps}
          />
      }
      {
        loading ?
          <div className='pk-select-loader-wrapper'>
            <div className='pk-select-loader'>
              <svg viewBox='22 22 44 44'>
                <circle className='path' cx='44' cy='44' r='19.5' fill='none' strokeWidth='4' />
              </svg>
            </div>
          </div>
          :
          hasRightIcon ?
            <span className={cx('pk-select-input-icon icon-right', icons.right.additionalClasses)} onClick={() => icons.right.onClick()} ref={icons.right.iconRef}>
              {icons.right.component}
            </span>
            :
            null
      }
    </div>
  )
}

const iconProps = {
  component: PropTypes.any,
  onClick: PropTypes.func,
  additionalClasses: PropTypes.string,
  iconRef: PropTypes.func
};

Input.propTypes = {
  value: PropTypes.any.isRequired,
  onChange: PropTypes.func.isRequired,
  onBlur: PropTypes.func,
  onFocus: PropTypes.func,
  disabled: PropTypes.bool,
  inputClasses: PropTypes.string,
  icons: PropTypes.shape({
    left: PropTypes.shape(iconProps),
    right: PropTypes.shape(iconProps),
  }),
  inputRef: PropTypes.func,
  placeHolder: PropTypes.string,
  loading: PropTypes.bool,
}

Input.defaultProps = {
  onChange: noop,
  onBlur: noop,
  onFocus: noop,
  disabled: false,
  inputClasses: '',
  value: '',
  icons: {},
  inputRef: noop,
  loading: false,
}

export default Input
